pub struct HoprKeyMapper<B> {
pub(crate) id_to_key: Cache<HoprKeyIdent, Option<OffchainPublicKey>, RandomState>,
pub(crate) key_to_id: Cache<OffchainPublicKey, Option<HoprKeyIdent>, RandomState>,
pub(crate) backend: Arc<B>,
}Fields
id_to_key: Cache<HoprKeyIdent, Option<OffchainPublicKey>, RandomState>key_to_id: Cache<OffchainPublicKey, Option<HoprKeyIdent>, RandomState>backend: Arc<B>Trait Implementations
Sourceimpl<B> Clone for HoprKeyMapper<B>
impl<B> Clone for HoprKeyMapper<B>
Sourceimpl<B> KeyIdMapping<KeyIdent, OffchainPublicKey> for HoprKeyMapper<B>
impl<B> KeyIdMapping<KeyIdent, OffchainPublicKey> for HoprKeyMapper<B>
Sourcefn map_key_to_id(&self, key: &OffchainPublicKey) -> Option<HoprKeyIdent>
fn map_key_to_id(&self, key: &OffchainPublicKey) -> Option<HoprKeyIdent>
Maps public key to its unique identifier.
Sourcefn map_id_to_public(&self, id: &HoprKeyIdent) -> Option<OffchainPublicKey>
fn map_id_to_public(&self, id: &HoprKeyIdent) -> Option<OffchainPublicKey>
Maps public key identifier to the actual public key.
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
Convenience method to map a slice of public keys to IDs.
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
Convenience method to map a slice of IDs to public keys.